#     Copyright 2025, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file


# TODO: Make these work

if False:

    class GenericInInstanceMethod:
        @property
        def get[T](self):
            print(f"GenericInInstanceMethod:get -> {T}")

        def method[T](self):
            print(f"GenericInInstanceMethod:method -> {T}")

    class GenericInStaticMethod:
        @staticmethod
        def method[T]():
            print(f"GenericInStaticMethod:method -> {T}")

    class GenericInClassMethod:
        @classmethod
        def method[T](cls):
            print(f"GenericInClassMethod:method -> {T}")

    GenericInInstanceMethod().get
    GenericInInstanceMethod().method()
    GenericInStaticMethod.method()
    GenericInClassMethod.method()


class Parent[T]:
    value: T
    print(T)


class Child[T](Parent[T]):
    another_value: int
    print(T)


class MutiTypeVarGeneric[T1, T2]:
    generic_value_1: T1
    generic_value_2: T2
    print(T1)
    print(T2)


class MutiParamSpecGeneric[**P1, **P2]:
    generic_value_1: P1
    generic_value_2: P2
    print(P1)
    print(P2)


try:
    print(T)
    print(T1)
    print(T2)
    print(P1)
    print(P2)
except NameError:
    print("!!!")

#     Python tests originally created or extracted from other peoples work. The
#     parts were too small to be protected.
#
#     Licensed under the Apache License, Version 2.0 (the "License");
#     you may not use this file except in compliance with the License.
#     You may obtain a copy of the License at
#
#        http://www.apache.org/licenses/LICENSE-2.0
#
#     Unless required by applicable law or agreed to in writing, software
#     distributed under the License is distributed on an "AS IS" BASIS,
#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#     See the License for the specific language governing permissions and
#     limitations under the License.



#     Copyright 2025, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file


"""Type operation specs."""

from .BuiltinParameterSpecs import BuiltinMethodParameterSpecBase


class TypeMethodSpec(BuiltinMethodParameterSpecBase):
    """Method spec of exactly the `type` built-in value/type."""

    __slots__ = ()

    method_prefix = "type"


type___prepare___spec = TypeMethodSpec(
    name="__prepare__", list_star_arg="args", dict_star_arg="kwargs"
)

#     Part of "Nuitka", an optimizing Python compiler that is compatible and
#     integrates with CPython, but also works on its own.
#
#     Licensed under the GNU Affero General Public License, Version 3 (the "License");
#     you may not use this file except in compliance with the License.
#     You may obtain a copy of the License at
#
#        http://www.gnu.org/licenses/agpl.txt
#
#     Unless required by applicable law or agreed to in writing, software
#     distributed under the License is distributed on an "AS IS" BASIS,
#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#     See the License for the specific language governing permissions and
#     limitations under the License.



#     Copyright 2025, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file


"""In this test, we show external data files to be found."""

# nuitka-project: --mode=onefile
# nuitka-project: --include-data-dir={MAIN_DIRECTORY}/external-data=external-data
# nuitka-project: --include-data-files-external=external-data

from __future__ import print_function

import os
import sys

for line in open(
    os.path.join(os.path.dirname(sys.argv[0]), "external-data/external-data.txt")
):
    print("External data:", line)

print("OK.")

#     Python test originally created or extracted from other peoples work. The
#     parts from me are licensed as below. It is at least Free Software where
#     it's copied from other people. In these cases, that will normally be
#     indicated.
#
#     Licensed under the Apache License, Version 2.0 (the "License");
#     you may not use this file except in compliance with the License.
#     You may obtain a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#     Unless required by applicable law or agreed to in writing, software
#     distributed under the License is distributed on an "AS IS" BASIS,
#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#     See the License for the specific language governing permissions and
#     limitations under the License.
